package customer.customerAgent;

import java.io.IOException;
import java.util.Properties;
import java.util.logging.Logger;

import golfCourse.Tools;
import golfCourse.agents.contactToOTASystemAgent.ContactToOTASystemAgent;
import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.agents.managerAgent.behaviours.ReceiveSystemErrorBehaviour;
import golfCourse.communication.services.ServiceFinder;
import golfCourse.communication.services.ServiceFinderException;
import golfCourse.properties.GolfCourseSystemProperties;
import jade.content.lang.sl.SLCodec;
import jade.core.Agent;
import jade.domain.DFService;
import jade.domain.FIPAException;
import jade.domain.FIPANames;
import jade.domain.FIPAAgentManagement.DFAgentDescription;
import jade.domain.FIPAAgentManagement.ServiceDescription;


/**
 * Agents created only for system test.
 */
public class CustomerAgent extends Agent{

	public final static String SERVICE_NAME = "Customer Services";
	public final static String SERVICE_TYPE = "customer-service";
	public final static String SERVICE_OWNERSHIP = "Customer";
		
	private static Logger logger = Logger.getLogger(CustomerAgent.class.getName());
	
	public static String CUSTOMER_SEARCH = "1";
	public static String MA_ANSWER = "MA answer";
		
	public String conversationId = "1";
    public String ma_conversationId = "2";

	public ServiceFinder golfService;
	
	protected void setup() {
		
		getContentManager().registerLanguage(new SLCodec(), FIPANames.ContentLanguage.FIPA_SL0);

		findServices();
		
		addBehaviour(new CustomerAgentBehaviour());
	}
	
	
	/**
	 * Register services in Directory Facilitator
	 */
	private void registerInDF() {
		try {
			ServiceDescription sd = getServiceDescription();			
			DFAgentDescription dfd = new DFAgentDescription();
			dfd.setName(getAID());
			dfd.addServices(sd);
			DFService.register(this, dfd);
			logger.info(getName() + " is register");
			
		} catch (FIPAException e) {
			logger.info("Cannot register customer agent at DF: " + e.getLocalizedMessage());
			doDelete();
		}
	}
	
	/**
	 * Search manager agent of Golf System.
	 * This agent:
	 * - read file OTA_GolfCourseSearchRQ.xml and send it to Manager Agent.
	 * - receive answer from Manager Agent and write it to file result.xml
	 */
	private void findServices()
	{
		try {
			golfService = new ServiceFinder(this, ManagerAgent.getServiceDescription());
		} catch(ServiceFinderException e)
		{
			logger.info(getLocalName() + ": manager agent not found");
		}
	}
	
	/**
	 * Returns information about the service this agent provides
	 * 
	 * @return service description
	 */
	public static ServiceDescription getServiceDescription() {
		ServiceDescription sd = new ServiceDescription();
		sd.setType(SERVICE_TYPE);
		sd.setName(SERVICE_NAME);
		sd.setOwnership(SERVICE_OWNERSHIP);
		return sd;
	}
}
