package customer.customerAgent;

import jade.core.AID;
import jade.core.behaviours.CyclicBehaviour;
import jade.lang.acl.ACLMessage;
import jade.lang.acl.MessageTemplate;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Properties;
import java.util.logging.Logger;



public class CustomerAgentBehaviour extends CyclicBehaviour{

	private static Logger logger = Logger.getLogger(CustomerAgentBehaviour.class.getName());
	
	private static final String CONVERSATION_ID = "CONVERSATION_ID";
	private static final String MA_CONVERSATION_ID="MA_CONVERSATION_ID";
	
	private String conversationId = "1";
	private String ma_conversationId = "2";

	/**
	 * Message template from customer (user)
	 */
	private final MessageTemplate customerMessage;
	
	/**
	 * Message template from Manager Agent of Golf System
	 */
	private final MessageTemplate fromMAMessage;

	
	public CustomerAgentBehaviour()
	{
		readProperties();
		customerMessage = MessageTemplate.MatchConversationId(this.conversationId);
		fromMAMessage = MessageTemplate.MatchConversationId(this.ma_conversationId);
	}
	
	public void action()
	{
		block();
		
		ACLMessage msg = myAgent.receive(customerMessage);
		if(msg!=null)
		{
			//logger.info(myAgent.getLocalName() + " received message from user.");
			logger.info(myAgent.getLocalName() + " received message from user.");
        	sendRequest(msg);
		}
		
		msg = myAgent.receive(fromMAMessage);
		if(msg!=null)
		{
			logger.info(myAgent.getLocalName() + " received message from manager agent");
			//logger.info(myAgent.getLocalName() + " received message from Manager Agent.");
        	writeAnswer(msg);
		}
	
	}
	
	/**
	 * Write answer to file results.xml
	 * @param ACLMessage - answer
	 */
	private void writeAnswer(ACLMessage msg) {
		String answer = msg.getContent();
		try {
			// TODO change file path -> from properties
			Date currentTime = new Date();
			SimpleDateFormat formater = new SimpleDateFormat("yyyy-MM-dd_HH-mm-ss");
			
			FileWriter fileWriter = new FileWriter(CustomerAgentProperties.CUSTOMER_RESULTS_PATH + "/CA_result_" + formater.format(currentTime) + ".xml");
			BufferedWriter bw = new BufferedWriter(fileWriter);
			bw.write(answer);
			bw.close();
			//logger.info(myAgent.getLocalName() + " has written the answer");
			logger.info(myAgent.getLocalName() + " has written the answer.");
		} catch(Exception e) {
			//logger.info(myAgent.getLocalName() + " exception during write answer: " + e.getLocalizedMessage());
			logger.info(myAgent.getLocalName() + " exception during write answer: " + e.getLocalizedMessage());
		}
	}
	
	/**
	 * Send OTA message to Manager Agent
	 * @param ACLMessage to Manager Agent
	 */
	private void sendRequest(ACLMessage msg) {
		String filePath = msg.getContent();
        String content = "";
        try {
        	if(filePath.equals("1")) {
        		//logger.info(myAgent.getLocalName() + " is reading sample file...");
        		logger.info(myAgent.getLocalName() + " is reading sample file...");
        		content = readFile(CustomerAgentProperties.EXAMPLE_GOLFCOURSE_SERCH_RQ);
        	}else {
        		//logger.info(myAgent.getLocalName() + " is reading user's file...");
        		logger.info(myAgent.getLocalName() + " is reading user's file...");
        		content = readFile(filePath);
        	}
        }
        catch(IOException e)
        {
        	//logger.info(myAgent.getLocalName() + ": error during reading file - " + e.getLocalizedMessage());
        	logger.info(myAgent.getLocalName() + ": error during reading file - " + e.getLocalizedMessage());
        	return;
        }
        sendMessage(content);
	}
	
	/**
	 * Read file from filePath
	 * @param file path
	 * @throws IOException
	 */
	private String readFile(String filePath) throws IOException
	{
		String file = "";
        BufferedReader br= new BufferedReader(new InputStreamReader(new FileInputStream(filePath)));
        String line = br.readLine();
        while(line!=null) {
        	file = file + line;
        	line = br.readLine();
        }
        return file;
	}
	
	/**
	 * Send message
	 * @param message
	 */
	private void sendMessage(String msg) {
		try {
		ACLMessage aclMessage = new ACLMessage(ACLMessage.INFORM);
		aclMessage.setConversationId(((CustomerAgent)myAgent).conversationId);
		aclMessage.addReceiver(new AID("MA", AID.ISLOCALNAME));
		aclMessage.setContent(msg);
		aclMessage.setContentObject(msg);
		myAgent.send(aclMessage);
		//logger.info(myAgent.getLocalName() + " sent message to manager agent");
		logger.info(myAgent.getLocalName() + " sent message to manager agent");
		} catch(Exception e) {
			//logger.info(myAgent.getLocalName() + ": error during sending message to MA - " + e.getLocalizedMessage());
			logger.info(myAgent.getLocalName() + ": error during sending message to MA - " + e.getLocalizedMessage());
		}
	}
	
	public static Properties loadProperties(String confURL) throws IOException {
		java.net.URL url = new java.net.URL(confURL);
		Properties conf = new Properties();
		conf.load(url.openStream());
		return conf;
	}
	
	/**
	 * Read user properties: count of TranslationAgents and SearchingAgents.
	 */
	private void readProperties()
	{
		try{
			Properties prop = loadProperties(CustomerAgentProperties.MESSAGE_PROPERTIES);
			this.conversationId = prop.getProperty(CONVERSATION_ID);
			this.ma_conversationId = prop.getProperty(MA_CONVERSATION_ID);
		}
		catch(IOException e)
		{
			// It's only warning - one SA and one TA will be created.
			logger.info("Customer Agent: cannot read message-properties file - " + e.getLocalizedMessage());
			//logger.info(getLocalName() + " cannot read agents-properties file - " + e.getLocalizedMessage());
		}
	}
}
