package golfCourse.agents;

import golfCourse.agents.managerAgent.behaviours.CustomerResponseBehaviour;
import golfCourse.communication.ontology.InfoMessage;
import golfCourse.communication.ontology.MA_system_error_action;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.behaviours.OneShotBehaviour;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class SendSystemErrorBehaviour extends OneShotBehaviour{

	private AID managerAID;
	private String errorMessage;
	private GolfCourseAgent myAgent;
	
	private static Logger logger = Logger.getMyLogger(SendSystemErrorBehaviour.class.getName());

	
	public SendSystemErrorBehaviour(String errorMessage, GolfCourseAgent agent)
	{
		this.managerAID = agent.managerAID;
		this.errorMessage = errorMessage;
		this.myAgent = agent;
	}
	
	public void action()
	{
		ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
		
		MA_system_error_action action = new MA_system_error_action();
		
		InfoMessage infoMessage = new InfoMessage();
		
		infoMessage.setMessage(this.errorMessage);
		
		action.setError_message(infoMessage);
		
		acl.setLanguage(myAgent.language);
		acl.setOntology(myAgent.golfCourseOntology.getName());
		acl.addReceiver(this.managerAID);
		
		try {
			myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), action));
			myAgent.send(acl);
		}
		catch(Exception e)
		{
			logger.info(myAgent.getLocalName() + ": cannot send system error message to MA - " + e.getMessage());
		}
	}
}
