package golfCourse.agents.contactToOTASystemAgent.handlers;

import golfCourse.agents.SendSystemErrorBehaviour;
import golfCourse.agents.contactToOTASystemAgent.ContactToOTASystemAgent;
import golfCourse.agents.contactToOTASystemAgent.ContactToOTASystemProperties;
import golfCourse.communication.ontology.CA_send_OTAGolfCourseAvailRQ;
import golfCourse.communication.ontology.OTAGolfCourseAvailRS_Message;
import golfCourse.communication.ontology.TA_translate_from_OTAGolfCourseAvailRS;
import golfCourse.communication.services.RequestHandler;
import jade.content.onto.basic.Action;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;

public class GolfCourseAvailHandler extends RequestHandler {
	
	private static Logger logger = Logger.getMyLogger(GolfCourseAvailHandler.class.getName());
	
	protected ContactToOTASystemAgent myAgent;
	
	public GolfCourseAvailHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		myAgent = (ContactToOTASystemAgent) a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
			try {
				logger.info(myAgent.getLocalName() + " receive OTAGolfCourseAvailRQ message from TA");
				CA_send_OTAGolfCourseAvailRQ action = (CA_send_OTAGolfCourseAvailRQ)act.getAction();
								
				TA_translate_from_OTAGolfCourseAvailRS responseAction = new TA_translate_from_OTAGolfCourseAvailRS();
				
				OTAGolfCourseAvailRS_Message otaMessage = new OTAGolfCourseAvailRS_Message();
				
				String otaString = generateOTAResponse();
				otaMessage.setOtaMessage(otaString);
				
				responseAction.setMessage_OTAGolfCourseAvailRS(otaMessage);
				
				ACLMessage response = request.createReply();
				
				responseAction.setCustomerMessageID(action.getCustomerMessageID());
				
				myAgent.getContentManager().fillContent(response, new Action(myAgent.getAID(), responseAction));
				
				logger.info(myAgent.getLocalName() + " send OTAGolfCourseAvailRS message to GolfCourseSystem");
				return response;
				
			} catch (Exception e) {
				myAgent.addBehaviour(new SendSystemErrorBehaviour(e.getMessage(), myAgent));
				logger.info("System error: " + myAgent.getLocalName() + " cannot realize request: " + e.getLocalizedMessage());
				throw new FailureException(e.getMessage());
			}
	}
	
	/**
	 * @return OTAGolfCourseAvailRS from example file.
	 */
	private String generateOTAResponse()
	{
		try {
			return readFile(ContactToOTASystemProperties.EXAMPLE_GOLF_COURSE_AVAIL_RS);
		}
		catch(IOException e)
		{
			logger.info(myAgent.getLocalName() + ": error during reading file " + e.getLocalizedMessage());
		}
		return "";
	}
	
	/**
	 * Read file from filePath
	 * @param file path
	 * @throws IOException
	 */
	private String readFile(String filePath) throws IOException
	{
		String file = "";
        BufferedReader br= new BufferedReader(new InputStreamReader(new FileInputStream(filePath)));
        String line = br.readLine();
        while(line!=null) {
        	file = file + line;
        	line = br.readLine();
        }
        return file;
	}

}
