package golfCourse.agents.managerAgent;

import golfCourse.agents.managerAgent.system.handlers.CustomerResponseHandler;
import golfCourse.agents.managerAgent.system.handlers.GenerateErrorMessageHandler;
import golfCourse.agents.managerAgent.system.handlers.GenerateOTAErrorMessageHandler;
import golfCourse.agents.managerAgent.system.handlers.GolfCourseAvailMapHandler;
import golfCourse.agents.managerAgent.system.handlers.ReceiveSystemErrorHandler;
import golfCourse.agents.managerAgent.system.handlers.SendConditionsHandler;
import golfCourse.agents.managerAgent.system.handlers.SendOntologiesResponseHandler;
import golfCourse.agents.managerAgent.system.handlers.ShowMessageHandler;
import golfCourse.communication.ontology.MA_GolfCourseAvailMap_receive;
import golfCourse.communication.ontology.MA_conditions_receive;
import golfCourse.communication.ontology.MA_generate_OTA_error_message;
import golfCourse.communication.ontology.MA_generate_error_message;
import golfCourse.communication.ontology.MA_send_OTAGolfCourseSearchRS;
import golfCourse.communication.ontology.MA_send_ontologies;
import golfCourse.communication.ontology.MA_show_error_message_action;
import golfCourse.communication.ontology.MA_system_error_action;
import golfCourse.communication.services.ActionDispatcher;
import jade.core.Agent;
import jade.domain.FIPAAgentManagement.NotUnderstoodException;
import jade.domain.FIPAAgentManagement.RefuseException;
import jade.lang.acl.ACLMessage;
import jade.lang.acl.MessageTemplate;
import jade.proto.AchieveREResponder;
import jade.proto.states.HandlerSelector;

public class ManagerAgentSystemResponder extends AchieveREResponder {

	public final String ACT_KEY = "__action" + hashCode();

	public ManagerAgentSystemResponder(Agent a, MessageTemplate mt) {
		super(a, mt);

		HandlerSelector selector = new ActionDispatcher(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY);
		
	   	selector.registerHandler(MA_send_OTAGolfCourseSearchRS.class.getName(),
				new CustomerResponseHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_GolfCourseAvailMap_receive.class.getName(),
				new GolfCourseAvailMapHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_generate_OTA_error_message.class.getName(),
				new GenerateOTAErrorMessageHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_system_error_action.class.getName(),
				new ReceiveSystemErrorHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_generate_error_message.class.getName(),
				new GenerateErrorMessageHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_conditions_receive.class.getName(),
				new SendConditionsHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_send_ontologies.class.getName(),
				new SendOntologiesResponseHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

	   	selector.registerHandler(MA_show_error_message_action.class.getName(),
				new ShowMessageHandler(myAgent, getDataStore(), REQUEST_KEY, ACT_KEY, RESULT_NOTIFICATION_KEY));

		registerPrepareResultNotification(selector);
	}
	
    protected ACLMessage prepareResponse(ACLMessage request) throws NotUnderstoodException, RefuseException {
    	// Don't say AGREE or REFUSE exlipictly; no response means AGREE
        return null;
    }
}
