package golfCourse.agents.managerAgent.behaviours;

import golfCourse.agents.managerAgent.ManagerAgent;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.OneShotBehaviour;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

import java.util.logging.Level;

/**
 * After getting response from TA.
 * Send OTA_GolfCourseSearchRS to customer.
 */
public class CustomerResponseBehaviour extends OneShotBehaviour{
	
	private String answer = null;
	private String customerAID = "";
	
	private static Logger logger = Logger.getMyLogger(CustomerResponseBehaviour.class.getName());

	private ManagerAgent myAgent;
	
	public CustomerResponseBehaviour(String otaMessage, String customerId, Agent myAgent)
	{
		this.myAgent = (ManagerAgent)myAgent;
		
		answer = otaMessage;
		customerAID = customerId;
	}
	
	public void action()
	{
		logger.info(myAgent.getLocalName() + " - customer response action");
		sendReply();
	}

	private void sendReply()
	{
		AID aid = new AID(customerAID, AID.ISGUID);
		
		sendMessage(aid, answer, myAgent.customerAnswer);
		logger.info(myAgent.getLocalName() + " sent response to customer " + aid.getLocalName());
	}
	
	private void sendMessage(AID aid, String message, String msg) {
		try {
			ACLMessage aclMessage = new ACLMessage(ACLMessage.INFORM);
			aclMessage.setConversationId(msg);
			aclMessage.addReceiver(aid);
			aclMessage.setContent(message);
			myAgent.send(aclMessage);
			logger.info(myAgent.getLocalName() + " sent response to customer " + aid.getLocalName());
			} catch(Exception e) {
				logger.log(Level.WARNING, myAgent.getLocalName() + " - exception during sending response to customer " + e.getMessage());
			}
	}
}
