package golfCourse.agents.managerAgent.customer.behaviours;

import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.communication.ontology.CloseSystemMessage;
import golfCourse.communication.ontology.Close_system_action;
import jade.content.lang.Codec.CodecException;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.OneShotBehaviour;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

import java.util.Iterator;
import java.util.List;
import java.util.logging.Level;

/**
 * Closes all agents in system.
 */
public class CloseSystemBehaviour extends OneShotBehaviour{

	private static Logger logger = Logger.getMyLogger(CloseSystemBehaviour.class.getName());
	
	private ManagerAgent myAgent;
	
	public CloseSystemBehaviour(Agent myAgent)
	{
		this.myAgent = (ManagerAgent)myAgent;
	}
	
	public void action()
	{
		logger.info(myAgent.getLocalName() + " - close system action");
		sendCloseMessages();
		myAgent.doDelete();
	}
	
	/**
	 * Sends messages about closing system to all agents.
	 */
	public void sendCloseMessages()
	{
		try{
			ACLMessage acl = createCloseMessage();
			sendToTranslationAgents(acl);
			sendToSearchAgents(acl);
			sendToDatabaseAgent(acl);
			sendToContactAgents(acl);
			myAgent.send(acl);
			logger.info(myAgent.getLocalName() + " sent close message to all agents in system");
		}catch(Exception e)
		{
			logger.info(myAgent.getLocalName() + " error during sending close message: " + e.getLocalizedMessage());		
		}
	}
	
	/**
	 * Add all translation agents to set of receivers close message.
	 * @param ACLMessage - close message.
	 */
	private void sendToTranslationAgents(ACLMessage msg)
	{
		List ta = ((ManagerAgent)myAgent).translationService.getAllNames();
		for(Iterator iter = ta.iterator(); iter.hasNext();)
		{
			AID aid = (AID)iter.next();
			msg.addReceiver(aid);
		}
	}
	
	/**
	 * Add all query agents to set of receivers close message.
	 * @param ACLMessage - close message.
	 */
	private void sendToSearchAgents(ACLMessage msg)
	{
		List sa = ((ManagerAgent)myAgent).searchingServices.getAllNames();
		for(Iterator iter = sa.iterator(); iter.hasNext();)
		{
			AID aid = (AID)iter.next();
			msg.addReceiver(aid);
		}
	}
	
	/**
	 * Add all contact to OTA agents to set of receivers close message.
	 * @param ACLMessage - close message.
	 */
	private void sendToContactAgents(ACLMessage msg)
	{
		List sa = ((ManagerAgent)myAgent).contactToExternalOTASystemServices.getAllNames();
		for(Iterator iter = sa.iterator(); iter.hasNext();)
		{
			AID aid = (AID)iter.next();
			msg.addReceiver(aid);
		}
	}
	
	/**
	 * Add all database agents to set of receivers close message.
	 * @param ACLMessage - close message.
	 */
	private void sendToDatabaseAgent(ACLMessage msg)
	{
		List dba = ((ManagerAgent)myAgent).databaseServices.getAllNames();
		for(Iterator iter = dba.iterator(); iter.hasNext();)
		{
			AID aid = (AID)iter.next();
			msg.addReceiver(aid);
		}
	}
	
	/**
	 * Creates close message.
	 * Create close_action and set it to content of close message.
	 * Set language and ontology to close message.
	 * @return ACLMessage - close message
	 * @throws OntologyException, CodecException
	 */
	private ACLMessage createCloseMessage() throws OntologyException, CodecException
	{
		ACLMessage aclMessage = new ACLMessage(ACLMessage.INFORM);
		Close_system_action action = new Close_system_action();
		CloseSystemMessage closeMessage = new CloseSystemMessage();
		closeMessage.setMessage("MA is closing system...");
		action.setCloseMessage(closeMessage);
		aclMessage.setLanguage(((ManagerAgent)myAgent).language);
		aclMessage.setOntology(((ManagerAgent)myAgent).golfCourseOntology.getName());
		 
		myAgent.getContentManager().fillContent(aclMessage, new Action(myAgent.getAID(), action));
		return aclMessage;
	}
}
