package golfCourse.agents.managerAgent.customer.behaviours;

import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.agents.managerAgent.behaviours.ReceiveSystemErrorBehaviour;
import golfCourse.communication.ontology.OTAGolfCourseSearchRQ_Message;
import golfCourse.communication.ontology.TA_translate_from_OTAGolfCourseSearchRQ;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.OneShotBehaviour;
import jade.lang.acl.ACLMessage;
import jade.lang.acl.UnreadableException;
import jade.util.Logger;

import java.util.logging.Level;

/**
 * After getting request from customer (Customer Agent)
 */
public class CustomerRequestBehaviour extends OneShotBehaviour{
	
	private static Logger logger = Logger.getMyLogger(CustomerRequestBehaviour.class.getName());

	private Object content = null;
	private ManagerAgent myAgent;
	
	private String customerAID = "";
	
	// TODO change message
	public CustomerRequestBehaviour(ACLMessage msg, Agent myAgent)
	{
		this.myAgent = (ManagerAgent)myAgent;
		
		logger.info(myAgent.getLocalName() + " receive message from customer: " + msg.getSender().getLocalName());
		
		try{
			content = msg.getContentObject();
		}
		catch(UnreadableException e)
		{
			logger.info(myAgent.getLocalName() + " error during reading message - " + e.getMessage());
		}
		catch(NullPointerException e)
		{
			logger.info(myAgent.getLocalName() + " error during reading message - " + e.getMessage());
		}
		
		customerAID = msg.getSender().getName();
	}
	
	public void action()
	{
		logger.info(myAgent.getLocalName() + " - customer request action");
		if(content!=null)
			sendMessageToTranslationAgent();
	}

	/**
	 * This method send customer message (OTA_GolfCourseSearchRQ) to TA.
	 */
	private void sendMessageToTranslationAgent()
	{
		AID aid = ((ManagerAgent)myAgent).translationService.getOne();
		
		if(aid == null)
		{
			myAgent.addBehaviour(new ReceiveSystemErrorBehaviour(myAgent.getLocalName() + ": no translation agents in system", myAgent));
			return;
		}
		
		TA_translate_from_OTAGolfCourseSearchRQ tfm = new TA_translate_from_OTAGolfCourseSearchRQ();
		
		tfm.setCustomerMessageID(customerAID);
		
		OTAGolfCourseSearchRQ_Message otaMsg = new OTAGolfCourseSearchRQ_Message();
		otaMsg.setOtaMessage(content.toString());
		tfm.setMessage_OTAGolfCourseSearchRQ(otaMsg);
		ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
		acl.setLanguage(((ManagerAgent)myAgent).language);
		acl.setOntology(((ManagerAgent)myAgent).golfCourseOntology.getName());
		
		 try {
			 myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), tfm));
			 acl.addReceiver(aid);
			 myAgent.send(acl);
			 logger.info(myAgent.getLocalName() + " sent customer message to TA");
		 }
		 catch(Exception e)
		 {
			 logger.info(myAgent.getLocalName() + " - exception during sending OTAMessage to TA: " + e.getMessage());
		 }
	}
}
