package golfCourse.agents.managerAgent.customer.behaviours;

import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.agents.managerAgent.behaviours.ReceiveSystemErrorBehaviour;
import golfCourse.communication.ontology.ClearDatabaseMessage;
import golfCourse.communication.ontology.DBA_clear_database;
import jade.content.lang.Codec.CodecException;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.OneShotBehaviour;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class RemoveDataBehaviour extends OneShotBehaviour{

	private Agent myAgent;
	private static Logger logger = Logger.getMyLogger(RemoveDataBehaviour.class.getName());
	
	public RemoveDataBehaviour(Agent myAgent) {
		this.myAgent = myAgent;
	}
	
	public void action() {
		logger.info(myAgent.getLocalName() + " received message about clear database");
		sendClearDataMessage();
	}
	
	private ACLMessage createRemoveDataMessage() throws OntologyException, CodecException
	{
		ACLMessage aclMessage = new ACLMessage(ACLMessage.INFORM);
		DBA_clear_database action = new DBA_clear_database();
		ClearDatabaseMessage clearMessage = new ClearDatabaseMessage();
		action.setClearMessage(clearMessage);
		aclMessage.setLanguage(((ManagerAgent)myAgent).language);
		aclMessage.setOntology(((ManagerAgent)myAgent).golfCourseOntology.getName());
		 
		myAgent.getContentManager().fillContent(aclMessage, new Action(myAgent.getAID(), action));
		return aclMessage;
	}
	
	public void sendClearDataMessage()
	{
		try{
			ACLMessage acl = createRemoveDataMessage();
			AID aid = ((ManagerAgent)myAgent).databaseServices.getOne();
			if(aid == null)
			{
				myAgent.addBehaviour(new ReceiveSystemErrorBehaviour(myAgent.getLocalName() + ": no database agent in system", myAgent));
				return;
			}
			acl.addReceiver(aid);
			myAgent.send(acl);
			logger.info(myAgent.getLocalName() + " sent remove data message to DBA");
		}catch(Exception e)
		{
			logger.info(myAgent.getLocalName() + " error during sending clear database message " + e.getLocalizedMessage());		
		}
	}
}
