package golfCourse.agents.managerAgent.system.handlers;

import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.agents.managerAgent.behaviours.ReceiveSystemErrorBehaviour;
import golfCourse.agents.searchAgent.handlers.FindGolfCoursesHandler;
import golfCourse.communication.ontology.MA_GolfCourseAvailMap_receive;
import golfCourse.communication.ontology.TA_translate_to_OTAGolfCourseAvailRQ;
import golfCourse.communication.services.RequestHandler;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class GolfCourseAvailMapHandler extends RequestHandler {

	private static Logger logger = Logger.getMyLogger(GolfCourseAvailMapHandler.class.getName());
	
	protected ManagerAgent myAgent;
	private String answer = null;
	private String customerAID = "";
	
	public GolfCourseAvailMapHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		myAgent = (ManagerAgent) a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
		
		AID aid = ((ManagerAgent)myAgent).translationService.getOne();
		
		if(aid == null)
		{
			myAgent.addBehaviour(new ReceiveSystemErrorBehaviour(myAgent.getLocalName() + ": no translation agents in system", myAgent));
			return null;
		}
		
		MA_GolfCourseAvailMap_receive action = (MA_GolfCourseAvailMap_receive)act.getAction();
		
		TA_translate_to_OTAGolfCourseAvailRQ tfm = new TA_translate_to_OTAGolfCourseAvailRQ();
		tfm.setMap(action.getMap_());
		tfm.setCustomerMessageID(request.getSender().getName());
		
		ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
		acl.setLanguage(((ManagerAgent)myAgent).language);
		acl.setOntology(((ManagerAgent)myAgent).golfCourseOntology.getName());
		
		 try {
			 myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), tfm));
			 acl.addReceiver(aid);
			 logger.info(myAgent.getLocalName() + " sent golf course avail map to TA");
			 return acl;
		 }
		 catch(Exception e)
		 {
			 logger.info(myAgent.getLocalName() + " - exception during sending golf course avail map to TA: " + e.getLocalizedMessage());
			 throw new FailureException(e.getMessage());
		 }
	}
}
