package golfCourse.agents.managerAgent.system.handlers;

import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.agents.managerAgent.behaviours.ReceiveSystemErrorBehaviour;
import golfCourse.agents.searchAgent.handlers.FindGolfCoursesHandler;
import golfCourse.communication.ontology.MA_conditions_receive;
import golfCourse.communication.ontology.SA_return_golf_courses;
import golfCourse.communication.services.RequestHandler;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class SendConditionsHandler extends RequestHandler {

	private static Logger logger = Logger.getMyLogger(SendConditionsHandler.class.getName());
	
	protected ManagerAgent myAgent;
	
	public SendConditionsHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		myAgent = (ManagerAgent) a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
		
		MA_conditions_receive requestAction = (MA_conditions_receive)act.getAction();
		
		SA_return_golf_courses action = new SA_return_golf_courses();
		action.setCoursesConditions(requestAction.getConditions_());
		action.setCustomerMessageID(request.getSender().getName());
		
		ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
		acl.setLanguage(((ManagerAgent)myAgent).language);
		acl.setOntology(((ManagerAgent)myAgent).golfCourseOntology.getName());
		
		 try {
			 myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), action));
			 
			 AID aid = myAgent.searchingServices.getOne();
				 
			 if(aid == null)
			 {
				myAgent.addBehaviour(new ReceiveSystemErrorBehaviour(myAgent.getLocalName() + ": no search agents in system", myAgent));
				return null;
			 }
			 acl.addReceiver(aid);
			 myAgent.send(acl);
			 logger.info(myAgent.getLocalName() + " sent customer message (conditions) to SA");
		 }
		 catch(Exception e)
		 {
			 logger.info(myAgent.getLocalName() + " - exception during sending message to SA: " + e.getLocalizedMessage());
			 throw new FailureException(e.getMessage());
		 }
		return null;
	}
}
