package golfCourse.agents.managerAgent.system.handlers;

import golfCourse.agents.managerAgent.ManagerAgent;
import golfCourse.agents.searchAgent.handlers.FindGolfCoursesHandler;
import golfCourse.communication.ontology.GolfSystemOntologies;
import golfCourse.communication.ontology.MA_send_ontologies;
import golfCourse.communication.services.RequestHandler;
import jade.content.lang.Codec;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class SendOntologiesResponseHandler extends RequestHandler {

	private static Logger logger = Logger.getMyLogger(SendOntologiesResponseHandler.class.getName());
	
	protected ManagerAgent myAgent;
	
	public SendOntologiesResponseHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		myAgent = (ManagerAgent) a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
		
		MA_send_ontologies action = (MA_send_ontologies)act.getAction();
		
		logger.info(myAgent.getLocalName() + " - send response with ontologies action");
		try {
			GolfSystemOntologies newAction = new GolfSystemOntologies();
			newAction.setOwlData(action.getOntologies_());
			newAction.setErrors(action.getErrors_());
			newAction.setWarnings(action.getWarnings_());
			ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
			AID receiver = new AID(action.getCustomerMessageID(), AID.ISGUID);
			acl.addReceiver(receiver);
			acl.setLanguage(myAgent.language);
			acl.setOntology(myAgent.golfCourseOntology.getName());
			myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), newAction));
		
			logger.info(myAgent.getLocalName() + " sent message to customer " + receiver.getLocalName());
			return acl;
		}
		catch(OntologyException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			throw new FailureException(e.getMessage());
		}
		catch(Codec.CodecException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			throw new FailureException(e.getMessage());
		}
	}
}
