package golfCourse.agents.translationAgent.handlers;

import golfCourse.agents.SendErrorToExternalBehaviour;
import golfCourse.agents.SendSystemErrorBehaviour;
import golfCourse.agents.translationAgent.TranslationAgent;
import golfCourse.communication.ontology.MA_send_ontologies;
import golfCourse.communication.ontology.OWLData;
import golfCourse.communication.ontology.TA_translate_from_OTAGolfCourseAvailRS;
import golfCourse.communication.services.RequestHandler;
import golfCourse.exceptions.TranslateException;
import golfCourse.translations.castor.OTA_GolfCourseAvailRS;
import golfCourse.translations.fromOTA.GolfCourseAvailRSTranslator;
import jade.content.lang.Codec;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;
import jade.util.leap.List;

public class TranslateFromOTAAvailRSHandler extends RequestHandler {
	
	private static Logger logger = Logger.getMyLogger(TranslateFromOTAAvailRSHandler.class.getName());

	private TranslationAgent myAgent;
	
	public TranslateFromOTAAvailRSHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		
		myAgent = (TranslationAgent)a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
		
		logger.info(myAgent.getLocalName() + " - translate from OTAGolfCourseAvailRS action");
		TA_translate_from_OTAGolfCourseAvailRS action = (TA_translate_from_OTAGolfCourseAvailRS)act.getAction();
		
		String ota = action.getMessage_OTAGolfCourseAvailRS().getOtaMessage();
		
		logger.info(myAgent.getLocalName() + " received OTAGolfCourseAvailRS");
		
		String messageID = action.getCustomerMessageID();
		
		try {
			GolfCourseAvailRSTranslator translator = new GolfCourseAvailRSTranslator(myAgent.domainGolfCourseTeeTimeModel, 
					myAgent.domainFeeModel, myAgent.domainPriceModel, myAgent.domainDescriptionModel);
			
			OTA_GolfCourseAvailRS otaMessage = translator.translateToOTA(ota);
			OWLData data = translator.translateToOntologies(otaMessage);
			List errors = translator.translateErrors(otaMessage);
			List warnings = translator.translateWarnings(otaMessage);
			
			ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
			
			MA_send_ontologies newAction = new MA_send_ontologies();
			
			newAction.setOntologies_(data);
			
			newAction.setErrors_(errors);
			newAction.setWarnings_(warnings);
			
			newAction.setCustomerMessageID(messageID);
			
			acl.setLanguage(myAgent.language);
			acl.setOntology(myAgent.golfCourseOntology.getName());
			
			AID aid = myAgent.managerAID;
			
			acl.addReceiver(aid);
			myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), newAction));
			
			logger.info(myAgent.getLocalName() + " sent instances of GolfCourseTeeTime ontology to MA");
			
			return acl;
		}
		catch(TranslateException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getLocalizedMessage());
			myAgent.addBehaviour(new SendErrorToExternalBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent, action.getCustomerMessageID()));
		}
		catch(OntologyException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getLocalizedMessage());		
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}
		catch(Codec.CodecException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getLocalizedMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}	
		return null;
	}
}
