package golfCourse.agents.translationAgent.handlers;

import golfCourse.agents.SendErrorToOTABehaviour;
import golfCourse.agents.SendSystemErrorBehaviour;
import golfCourse.agents.translationAgent.TranslationAgent;
import golfCourse.communication.ontology.Conditions;
import golfCourse.communication.ontology.SA_search_golf_courses;
import golfCourse.communication.ontology.TA_translate_from_OTAGolfCourseSearchRQ;
import golfCourse.communication.services.RequestHandler;
import golfCourse.exceptions.TranslateException;
import golfCourse.translations.fromOTA.GolfCourseSearchRQTranslator;
import jade.content.lang.Codec;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;


public class TranslateFromOTASearchRQHandler extends RequestHandler {
	
	private static Logger logger = Logger.getMyLogger(TranslateFromOTASearchRQHandler.class.getName());
	
	private TranslationAgent myAgent;
	
	public TranslateFromOTASearchRQHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		
		myAgent = (TranslationAgent)a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
		
		logger.info(myAgent.getLocalName() + " - translate from OTAGolfCourseSearchRQ action");
		logger.info(myAgent.getLocalName() + " received OTAGolfCourseSearchRQ message");
		TA_translate_from_OTAGolfCourseSearchRQ action = (TA_translate_from_OTAGolfCourseSearchRQ)act.getAction();
		String ota = action.getMessage_OTAGolfCourseSearchRQ().getOtaMessage();
		String messageID = action.getCustomerMessageID();
		
		try {			
			Conditions conditions = GolfCourseSearchRQTranslator.translateFromOTA(ota);
			ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
			SA_search_golf_courses newAction = new SA_search_golf_courses();
			newAction.setCoursesConditions(conditions);
			
			newAction.setCustomerMessageID(messageID);
			
			acl.setLanguage(((TranslationAgent)myAgent).language);
			acl.setOntology(((TranslationAgent)myAgent).golfCourseOntology.getName());
			
			AID aid = ((TranslationAgent)myAgent).searchingService.getOne();
			if(aid == null)
			 {
				myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": no search agents in system", myAgent));
				return null;
			 }
			 
			myAgent.getContentManager().fillContent(acl, new Action(aid, newAction));
			acl.addReceiver(aid);			
			logger.info(myAgent.getLocalName() + " sent conditions to SA");
			return acl;
		}
		catch(TranslateException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());	
			myAgent.addBehaviour(new SendErrorToOTABehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent, action.getCustomerMessageID()));
		}
		catch(OntologyException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}
		catch(Codec.CodecException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}		
		return null;
	}	
}
