package golfCourse.agents.translationAgent.handlers;

import golfCourse.agents.SendInfoAboutErrorBehaviour;
import golfCourse.agents.SendSystemErrorBehaviour;
import golfCourse.agents.translationAgent.TranslationAgent;
import golfCourse.communication.ontology.DBA_save_golf_courses;
import golfCourse.communication.ontology.OWLData;
import golfCourse.communication.ontology.TA_translate_from_OTAGolfCourseSearchRS;
import golfCourse.communication.services.RequestHandler;
import golfCourse.exceptions.TranslateException;
import golfCourse.translations.fromOTA.GolfCourseSearchRSTranslator;
import jade.content.lang.Codec;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class TranslateFromOTASearchRSHandler extends RequestHandler {
	
	private static Logger logger = Logger.getMyLogger(TranslateFromOTASearchRSHandler.class.getName());
	
	private TranslationAgent myAgent;
	
	public TranslateFromOTASearchRSHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		
		myAgent = (TranslationAgent)a;
	}

	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException {
		
		logger.info(myAgent.getLocalName() + " - translate from OTAGolfCourseSearchRS action");

		logger.info(myAgent.getLocalName() + " receive OTAGolfCourseSearchRS message");
		
		TA_translate_from_OTAGolfCourseSearchRS action = (TA_translate_from_OTAGolfCourseSearchRS)act.getAction();
		String ota = action.getOtaGolfCourseSearchRS().getOtaMessage();
		
		try {
			GolfCourseSearchRSTranslator golfCourseSearchRS = new GolfCourseSearchRSTranslator(myAgent.domainGolfCourseModel, myAgent.domainAddressModel, myAgent.domainContactsModel);
			OWLData instancesOfOntologies = golfCourseSearchRS.translateGolfCoursesToOntologies(ota);
			
			ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
			
			DBA_save_golf_courses newAction = new DBA_save_golf_courses();
			
			newAction.setGolfCourses(instancesOfOntologies);
			
			acl.setLanguage(myAgent.language);
			acl.setOntology(myAgent.golfCourseOntology.getName());
			
			AID aid = myAgent.savingService.getOne();
			
			if(aid == null)
			 {
				myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": no search agents in system", myAgent));
				return null;
			 }
			 
			myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), newAction));
			acl.addReceiver(aid);

			logger.info(myAgent.getLocalName() + " sent results to DBA");
			return acl;
		}
		catch(TranslateException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendInfoAboutErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}
		catch(OntologyException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}
		catch(Codec.CodecException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}	
		return null;
	}
}
