package golfCourse.agents.translationAgent.handlers;

import golfCourse.agents.SendErrorToExternalBehaviour;
import golfCourse.agents.SendSystemErrorBehaviour;
import golfCourse.agents.translationAgent.TranslationAgent;
import golfCourse.communication.ontology.CA_send_OTAGolfCourseAvailRQ;
import golfCourse.communication.ontology.Map;
import golfCourse.communication.ontology.OTAGolfCourseAvailRQ_Message;
import golfCourse.communication.ontology.TA_translate_to_OTAGolfCourseAvailRQ;
import golfCourse.communication.services.RequestHandler;
import golfCourse.exceptions.TranslateException;
import golfCourse.translations.toOTA.GolfCourseAvailRQTranslator;
import jade.content.lang.Codec;
import jade.content.onto.OntologyException;
import jade.content.onto.basic.Action;
import jade.core.AID;
import jade.core.Agent;
import jade.core.behaviours.DataStore;
import jade.domain.FIPAAgentManagement.FailureException;
import jade.lang.acl.ACLMessage;
import jade.util.Logger;

public class TranslateToOTAGolfCourseAvailRQHandler extends RequestHandler {
	
	private static Logger logger = Logger.getMyLogger(TranslateToOTAGolfCourseAvailRQHandler.class.getName());

	private TranslationAgent myAgent;
	
	public TranslateToOTAGolfCourseAvailRQHandler(Agent a, DataStore ds, Object requestKey,
			Object actKey, Object notificationKey) {
		super(a, ds, requestKey, actKey, notificationKey);
		
		myAgent = (TranslationAgent)a;
	}
	
	protected final ACLMessage prepareResponse(ACLMessage request, Action act) throws FailureException 
	{
		logger.info(myAgent.getLocalName() + " - translate to OTAGolfCourseAvailRQ action");
		logger.info(myAgent.getLocalName() + " received map - GolfCourseAvailRQ");

		TA_translate_to_OTAGolfCourseAvailRQ action = (TA_translate_to_OTAGolfCourseAvailRQ)act.getAction();

		Map map = action.getMap();
		
		try {
			GolfCourseAvailRQTranslator golfCourseAvailRQ = new GolfCourseAvailRQTranslator();
			
			String ota = golfCourseAvailRQ.translateToOTA(map);
			
			OTAGolfCourseAvailRQ_Message message = new OTAGolfCourseAvailRQ_Message();
			message.setOtaMessage(ota);
			
			ACLMessage acl = new ACLMessage(ACLMessage.INFORM);
			
			CA_send_OTAGolfCourseAvailRQ newAction = new CA_send_OTAGolfCourseAvailRQ();
			
			newAction.setGolfCourseAvailRQ(message);
			newAction.setCustomerMessageID(action.getCustomerMessageID());
			
			acl.setLanguage(myAgent.language);
			acl.setOntology(myAgent.golfCourseOntology.getName());
			
			AID aid = myAgent.cotactWithOTASystemsService.getOne();
			
			if(aid == null)
			 {
				myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": no contact agents in system", myAgent));
				return null;
			 }
			
			acl.addReceiver(aid);
			 
			myAgent.getContentManager().fillContent(acl, new Action(myAgent.getAID(), newAction));
			
			logger.info(myAgent.getLocalName() + " send OTAGolfCourseAvailRQ to agent response for contacts with external OTA system");
			return acl;
		}
		catch(TranslateException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendErrorToExternalBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent, action.getCustomerMessageID()));
		}
		catch(OntologyException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}
		catch(Codec.CodecException e)
		{
			logger.info(myAgent.getLocalName() + ": " + e.getMessage());
			myAgent.addBehaviour(new SendSystemErrorBehaviour(myAgent.getLocalName() + ": " + e.getMessage(), myAgent));
		}
		return null;
	}
}
