

package golfCourse.ontologies.jastor.contacts;

import com.ibm.adtech.jastor.*;
import com.hp.hpl.jena.rdf.model.Resource;
import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.Statement;
import com.hp.hpl.jena.rdf.model.StmtIterator;
import com.hp.hpl.jena.vocabulary.RDF;

/**
 * Factory for instantiating objects for ontology classes in the Contacts ontology.  The
 * get methods leave the model unchanged and return a Java view of the object in the model.  The create methods
 * may add certain baseline properties to the model such as rdf:type and any properties with hasValue restrictions.
 * <p>(URI: file:///D:/ontologies/domain/Contacts/Contacts)</p>
 * <br>
 * RDF Schema Standard Properties <br>
 * 	label : Contacts Ontology <br>
 * <br>
 * <br>
 */
public class ContactsFactory extends com.ibm.adtech.jastor.ThingFactory { 



	/**
	 * Create a new instance of ContactSrvcCode.  Adds the rdf:type property for the given resource to the model.
	 * @param resource The resource of the ContactSrvcCode
	 * @param model the Jena Model.
	 */
	public static ContactSrvcCode createContactSrvcCode(Resource resource, Model model) throws JastorException {
		return golfCourse.ontologies.jastor.contacts.ContactSrvcCodeImpl.createContactSrvcCode(resource,model);
	}
	
	/**
	 * Create a new instance of ContactSrvcCode.  Adds the rdf:type property for the given resource to the model.
	 * @param uri The uri of the ContactSrvcCode
	 * @param model the Jena Model.
	 */
	public static ContactSrvcCode createContactSrvcCode(String uri, Model model) throws JastorException {
		ContactSrvcCode obj = golfCourse.ontologies.jastor.contacts.ContactSrvcCodeImpl.createContactSrvcCode(model.createResource(uri), model);
		return obj;
	}
	
	/**
	 * Create a new instance of ContactSrvcCode.  Leaves the model unchanged.
	 * @param uri The uri of the ContactSrvcCode
	 * @param model the Jena Model.
	 */
	public static ContactSrvcCode getContactSrvcCode(String uri, Model model) throws JastorException {
		return getContactSrvcCode(model.createResource(uri),model);
	}
	
	/**
	 * Create a new instance of ContactSrvcCode.  Leaves the model unchanged.
	 * @param resource The resource of the ContactSrvcCode
	 * @param model the Jena Model.
	 */
	public static ContactSrvcCode getContactSrvcCode(Resource resource, Model model) throws JastorException {
		String code = (model.hashCode()*17 + golfCourse.ontologies.jastor.contacts.ContactSrvcCode.class.hashCode()) + resource.toString();
		golfCourse.ontologies.jastor.contacts.ContactSrvcCodeImpl obj = (golfCourse.ontologies.jastor.contacts.ContactSrvcCodeImpl)objects.get(code);
		if (obj == null) {
			obj = golfCourse.ontologies.jastor.contacts.ContactSrvcCodeImpl.getContactSrvcCode(resource, model);
			if (obj == null)
				return null;
			objects.put(code, obj);
		}
		return obj;
	}
	
	/**
	 * Return an instance of ContactSrvcCode for every resource in the model with rdf:Type file:///D:/ontologies/domain/Contacts/Contacts#ContactSrvcCode
	 * @param model the Jena Model
	 * @return a List of ContactSrvcCode
	 */
	public static java.util.List getAllContactSrvcCode(Model model) throws JastorException {
		StmtIterator it = model.listStatements(null,RDF.type,ContactSrvcCode.TYPE);
		java.util.List list = new java.util.ArrayList();
		while (it.hasNext()) {
			Statement stmt = it.nextStatement();
			list.add(getContactSrvcCode(stmt.getSubject(),model));
		}
		return list;
	}
	

	/**
	 * Create a new instance of Contacts.  Adds the rdf:type property for the given resource to the model.
	 * @param resource The resource of the Contacts
	 * @param model the Jena Model.
	 */
	public static Contacts createContacts(Resource resource, Model model) throws JastorException {
		return golfCourse.ontologies.jastor.contacts.ContactsImpl.createContacts(resource,model);
	}
	
	/**
	 * Create a new instance of Contacts.  Adds the rdf:type property for the given resource to the model.
	 * @param uri The uri of the Contacts
	 * @param model the Jena Model.
	 */
	public static Contacts createContacts(String uri, Model model) throws JastorException {
		Contacts obj = golfCourse.ontologies.jastor.contacts.ContactsImpl.createContacts(model.createResource(uri), model);
		return obj;
	}
	
	/**
	 * Create a new instance of Contacts.  Leaves the model unchanged.
	 * @param uri The uri of the Contacts
	 * @param model the Jena Model.
	 */
	public static Contacts getContacts(String uri, Model model) throws JastorException {
		return getContacts(model.createResource(uri),model);
	}
	
	/**
	 * Create a new instance of Contacts.  Leaves the model unchanged.
	 * @param resource The resource of the Contacts
	 * @param model the Jena Model.
	 */
	public static Contacts getContacts(Resource resource, Model model) throws JastorException {
		String code = (model.hashCode()*17 + golfCourse.ontologies.jastor.contacts.Contacts.class.hashCode()) + resource.toString();
		golfCourse.ontologies.jastor.contacts.ContactsImpl obj = (golfCourse.ontologies.jastor.contacts.ContactsImpl)objects.get(code);
		if (obj == null) {
			obj = golfCourse.ontologies.jastor.contacts.ContactsImpl.getContacts(resource, model);
			if (obj == null)
				return null;
			objects.put(code, obj);
		}
		return obj;
	}
	
	/**
	 * Return an instance of Contacts for every resource in the model with rdf:Type file:///D:/ontologies/domain/Contacts/Contacts#Contacts
	 * @param model the Jena Model
	 * @return a List of Contacts
	 */
	public static java.util.List getAllContacts(Model model) throws JastorException {
		StmtIterator it = model.listStatements(null,RDF.type,Contacts.TYPE);
		java.util.List list = new java.util.ArrayList();
		while (it.hasNext()) {
			Statement stmt = it.nextStatement();
			list.add(getContacts(stmt.getSubject(),model));
		}
		return list;
	}
	

	/**
	 * Create a new instance of UseType.  Adds the rdf:type property for the given resource to the model.
	 * @param resource The resource of the UseType
	 * @param model the Jena Model.
	 */
	public static UseType createUseType(Resource resource, Model model) throws JastorException {
		return golfCourse.ontologies.jastor.contacts.UseTypeImpl.createUseType(resource,model);
	}
	
	/**
	 * Create a new instance of UseType.  Adds the rdf:type property for the given resource to the model.
	 * @param uri The uri of the UseType
	 * @param model the Jena Model.
	 */
	public static UseType createUseType(String uri, Model model) throws JastorException {
		UseType obj = golfCourse.ontologies.jastor.contacts.UseTypeImpl.createUseType(model.createResource(uri), model);
		return obj;
	}
	
	/**
	 * Create a new instance of UseType.  Leaves the model unchanged.
	 * @param uri The uri of the UseType
	 * @param model the Jena Model.
	 */
	public static UseType getUseType(String uri, Model model) throws JastorException {
		return getUseType(model.createResource(uri),model);
	}
	
	/**
	 * Create a new instance of UseType.  Leaves the model unchanged.
	 * @param resource The resource of the UseType
	 * @param model the Jena Model.
	 */
	public static UseType getUseType(Resource resource, Model model) throws JastorException {
		String code = (model.hashCode()*17 + golfCourse.ontologies.jastor.contacts.UseType.class.hashCode()) + resource.toString();
		golfCourse.ontologies.jastor.contacts.UseTypeImpl obj = (golfCourse.ontologies.jastor.contacts.UseTypeImpl)objects.get(code);
		if (obj == null) {
			obj = golfCourse.ontologies.jastor.contacts.UseTypeImpl.getUseType(resource, model);
			if (obj == null)
				return null;
			objects.put(code, obj);
		}
		return obj;
	}
	
	/**
	 * Return an instance of UseType for every resource in the model with rdf:Type file:///D:/ontologies/domain/Contacts/Contacts#UseType
	 * @param model the Jena Model
	 * @return a List of UseType
	 */
	public static java.util.List getAllUseType(Model model) throws JastorException {
		StmtIterator it = model.listStatements(null,RDF.type,UseType.TYPE);
		java.util.List list = new java.util.ArrayList();
		while (it.hasNext()) {
			Statement stmt = it.nextStatement();
			list.add(getUseType(stmt.getSubject(),model));
		}
		return list;
	}
	

	/**
	 * Create a new instance of ContactTechnology.  Adds the rdf:type property for the given resource to the model.
	 * @param resource The resource of the ContactTechnology
	 * @param model the Jena Model.
	 */
	public static ContactTechnology createContactTechnology(Resource resource, Model model) throws JastorException {
		return golfCourse.ontologies.jastor.contacts.ContactTechnologyImpl.createContactTechnology(resource,model);
	}
	
	/**
	 * Create a new instance of ContactTechnology.  Adds the rdf:type property for the given resource to the model.
	 * @param uri The uri of the ContactTechnology
	 * @param model the Jena Model.
	 */
	public static ContactTechnology createContactTechnology(String uri, Model model) throws JastorException {
		ContactTechnology obj = golfCourse.ontologies.jastor.contacts.ContactTechnologyImpl.createContactTechnology(model.createResource(uri), model);
		return obj;
	}
	
	/**
	 * Create a new instance of ContactTechnology.  Leaves the model unchanged.
	 * @param uri The uri of the ContactTechnology
	 * @param model the Jena Model.
	 */
	public static ContactTechnology getContactTechnology(String uri, Model model) throws JastorException {
		return getContactTechnology(model.createResource(uri),model);
	}
	
	/**
	 * Create a new instance of ContactTechnology.  Leaves the model unchanged.
	 * @param resource The resource of the ContactTechnology
	 * @param model the Jena Model.
	 */
	public static ContactTechnology getContactTechnology(Resource resource, Model model) throws JastorException {
		String code = (model.hashCode()*17 + golfCourse.ontologies.jastor.contacts.ContactTechnology.class.hashCode()) + resource.toString();
		golfCourse.ontologies.jastor.contacts.ContactTechnologyImpl obj = (golfCourse.ontologies.jastor.contacts.ContactTechnologyImpl)objects.get(code);
		if (obj == null) {
			obj = golfCourse.ontologies.jastor.contacts.ContactTechnologyImpl.getContactTechnology(resource, model);
			if (obj == null)
				return null;
			objects.put(code, obj);
		}
		return obj;
	}
	
	/**
	 * Return an instance of ContactTechnology for every resource in the model with rdf:Type file:///D:/ontologies/domain/Contacts/Contacts#ContactTechnology
	 * @param model the Jena Model
	 * @return a List of ContactTechnology
	 */
	public static java.util.List getAllContactTechnology(Model model) throws JastorException {
		StmtIterator it = model.listStatements(null,RDF.type,ContactTechnology.TYPE);
		java.util.List list = new java.util.ArrayList();
		while (it.hasNext()) {
			Statement stmt = it.nextStatement();
			list.add(getContactTechnology(stmt.getSubject(),model));
		}
		return list;
	}
	

	/**
	 * Create a new instance of LocationType.  Adds the rdf:type property for the given resource to the model.
	 * @param resource The resource of the LocationType
	 * @param model the Jena Model.
	 */
	public static LocationType createLocationType(Resource resource, Model model) throws JastorException {
		return golfCourse.ontologies.jastor.contacts.LocationTypeImpl.createLocationType(resource,model);
	}
	
	/**
	 * Create a new instance of LocationType.  Adds the rdf:type property for the given resource to the model.
	 * @param uri The uri of the LocationType
	 * @param model the Jena Model.
	 */
	public static LocationType createLocationType(String uri, Model model) throws JastorException {
		LocationType obj = golfCourse.ontologies.jastor.contacts.LocationTypeImpl.createLocationType(model.createResource(uri), model);
		return obj;
	}
	
	/**
	 * Create a new instance of LocationType.  Leaves the model unchanged.
	 * @param uri The uri of the LocationType
	 * @param model the Jena Model.
	 */
	public static LocationType getLocationType(String uri, Model model) throws JastorException {
		return getLocationType(model.createResource(uri),model);
	}
	
	/**
	 * Create a new instance of LocationType.  Leaves the model unchanged.
	 * @param resource The resource of the LocationType
	 * @param model the Jena Model.
	 */
	public static LocationType getLocationType(Resource resource, Model model) throws JastorException {
		String code = (model.hashCode()*17 + golfCourse.ontologies.jastor.contacts.LocationType.class.hashCode()) + resource.toString();
		golfCourse.ontologies.jastor.contacts.LocationTypeImpl obj = (golfCourse.ontologies.jastor.contacts.LocationTypeImpl)objects.get(code);
		if (obj == null) {
			obj = golfCourse.ontologies.jastor.contacts.LocationTypeImpl.getLocationType(resource, model);
			if (obj == null)
				return null;
			objects.put(code, obj);
		}
		return obj;
	}
	
	/**
	 * Return an instance of LocationType for every resource in the model with rdf:Type file:///D:/ontologies/domain/Contacts/Contacts#LocationType
	 * @param model the Jena Model
	 * @return a List of LocationType
	 */
	public static java.util.List getAllLocationType(Model model) throws JastorException {
		StmtIterator it = model.listStatements(null,RDF.type,LocationType.TYPE);
		java.util.List list = new java.util.ArrayList();
		while (it.hasNext()) {
			Statement stmt = it.nextStatement();
			list.add(getLocationType(stmt.getSubject(),model));
		}
		return list;
	}
	
	
	/**
	 * Returns an instance of an interface for the given Resource.  The return instance is guaranteed to 
	 * implement the most specific interface in *some* hierarchy in which the Resource participates.  The behavior
	 * is unspecified for resources with RDF types from different hierarchies.
	 * @return an instance of Thing
	 */
	public static Thing getThing(com.hp.hpl.jena.rdf.model.Resource res, com.hp.hpl.jena.rdf.model.Model model) throws JastorException {
		if (res.hasProperty(RDF.type,model.getResource("file:///D:/ontologies/domain/Contacts/Contacts#LocationType"))) {
			return getLocationType(res,model);
		}
		if (res.hasProperty(RDF.type,model.getResource("file:///D:/ontologies/domain/Contacts/Contacts#ContactTechnology"))) {
			return getContactTechnology(res,model);
		}
		if (res.hasProperty(RDF.type,model.getResource("file:///D:/ontologies/domain/Contacts/Contacts#UseType"))) {
			return getUseType(res,model);
		}
		if (res.hasProperty(RDF.type,model.getResource("file:///D:/ontologies/domain/Contacts/Contacts#Contacts"))) {
			return getContacts(res,model);
		}
		if (res.hasProperty(RDF.type,model.getResource("file:///D:/ontologies/domain/Contacts/Contacts#ContactSrvcCode"))) {
			return getContactSrvcCode(res,model);
		}
		return new ThingImpl(res,model);
	}
	
	/**
	 * Returns an instance of an interface for the given Resource URI.  The return instance is guaranteed to 
	 * implement the most specific interface in *some* hierarchy in which the Resource participates.  The behavior
	 * is unspecified for resources with RDF types from different hierarchies.
	 * @return an instance of Thing
	 */
	public static Thing getThing(String uri, com.hp.hpl.jena.rdf.model.Model model) throws JastorException {
		return getThing(model.getResource(uri),model);
	}

	/**
	 * Return a list of compatible interfaces for the given type.  Searches through all ontology classes
	 * in the Contacts ontology.  The list is sorted according to the topological sort
	 * of the class hierarchy
	 * @return a List of type java.lang.Class
	 */
	public static java.util.List listCompatibleInterfaces (com.hp.hpl.jena.rdf.model.Resource type) {
		java.util.List types = new java.util.ArrayList();
		if (type.equals(golfCourse.ontologies.jastor.contacts.LocationType.TYPE)) {
			types.add(golfCourse.ontologies.jastor.contacts.LocationType.class);
		}
		if (type.equals(golfCourse.ontologies.jastor.contacts.ContactTechnology.TYPE)) {
			types.add(golfCourse.ontologies.jastor.contacts.ContactTechnology.class);
		}
		if (type.equals(golfCourse.ontologies.jastor.contacts.UseType.TYPE)) {
			types.add(golfCourse.ontologies.jastor.contacts.UseType.class);
		}
		if (type.equals(golfCourse.ontologies.jastor.contacts.Contacts.TYPE)) {
			types.add(golfCourse.ontologies.jastor.contacts.Contacts.class);
		}
		if (type.equals(golfCourse.ontologies.jastor.contacts.ContactSrvcCode.TYPE)) {
			types.add(golfCourse.ontologies.jastor.contacts.ContactSrvcCode.class);
		}
		return types;
	}
}