

package golfCourse.ontologies.jastor.location;

import com.ibm.adtech.jastor.*;
import com.hp.hpl.jena.rdf.model.Resource;
import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.Statement;
import com.hp.hpl.jena.rdf.model.StmtIterator;
import com.hp.hpl.jena.vocabulary.RDF;

/**
 * Factory for instantiating objects for ontology classes in the AddressRecord ontology.  The
 * get methods leave the model unchanged and return a Java view of the object in the model.  The create methods
 * may add certain baseline properties to the model such as rdf:type and any properties with hasValue restrictions.
 * <p>(URI: file:///D:/ontologies/domain/Location/AddressRecord)</p>
 * <br>
 * RDF Schema Standard Properties <br>
 * 	label : AddressRecord Ontology <br>
 * <br>
 * <br>
 */
public class AddressRecordFactory extends com.ibm.adtech.jastor.ThingFactory { 



	/**
	 * Create a new instance of AddressRecord.  Adds the rdf:type property for the given resource to the model.
	 * @param resource The resource of the AddressRecord
	 * @param model the Jena Model.
	 */
	public static AddressRecord createAddressRecord(Resource resource, Model model) throws JastorException {
		return golfCourse.ontologies.jastor.location.AddressRecordImpl.createAddressRecord(resource,model);
	}
	
	/**
	 * Create a new instance of AddressRecord.  Adds the rdf:type property for the given resource to the model.
	 * @param uri The uri of the AddressRecord
	 * @param model the Jena Model.
	 */
	public static AddressRecord createAddressRecord(String uri, Model model) throws JastorException {
		AddressRecord obj = golfCourse.ontologies.jastor.location.AddressRecordImpl.createAddressRecord(model.createResource(uri), model);
		return obj;
	}
	
	/**
	 * Create a new instance of AddressRecord.  Leaves the model unchanged.
	 * @param uri The uri of the AddressRecord
	 * @param model the Jena Model.
	 */
	public static AddressRecord getAddressRecord(String uri, Model model) throws JastorException {
		return getAddressRecord(model.createResource(uri),model);
	}
	
	/**
	 * Create a new instance of AddressRecord.  Leaves the model unchanged.
	 * @param resource The resource of the AddressRecord
	 * @param model the Jena Model.
	 */
	public static AddressRecord getAddressRecord(Resource resource, Model model) throws JastorException {
		String code = (model.hashCode()*17 + golfCourse.ontologies.jastor.location.AddressRecord.class.hashCode()) + resource.toString();
		golfCourse.ontologies.jastor.location.AddressRecordImpl obj = (golfCourse.ontologies.jastor.location.AddressRecordImpl)objects.get(code);
		if (obj == null) {
			obj = golfCourse.ontologies.jastor.location.AddressRecordImpl.getAddressRecord(resource, model);
			if (obj == null)
				return null;
			objects.put(code, obj);
		}
		return obj;
	}
	
	/**
	 * Return an instance of AddressRecord for every resource in the model with rdf:Type file:///D:/ontologies/domain/Location/AddressRecord#AddressRecord
	 * @param model the Jena Model
	 * @return a List of AddressRecord
	 */
	public static java.util.List getAllAddressRecord(Model model) throws JastorException {
		StmtIterator it = model.listStatements(null,RDF.type,AddressRecord.TYPE);
		java.util.List list = new java.util.ArrayList();
		while (it.hasNext()) {
			Statement stmt = it.nextStatement();
			list.add(getAddressRecord(stmt.getSubject(),model));
		}
		return list;
	}
	
	
	/**
	 * Returns an instance of an interface for the given Resource.  The return instance is guaranteed to 
	 * implement the most specific interface in *some* hierarchy in which the Resource participates.  The behavior
	 * is unspecified for resources with RDF types from different hierarchies.
	 * @return an instance of Thing
	 */
	public static Thing getThing(com.hp.hpl.jena.rdf.model.Resource res, com.hp.hpl.jena.rdf.model.Model model) throws JastorException {
		if (res.hasProperty(RDF.type,model.getResource("file:///D:/ontologies/domain/Location/AddressRecord#AddressRecord"))) {
			return getAddressRecord(res,model);
		}
		return new ThingImpl(res,model);
	}
	
	/**
	 * Returns an instance of an interface for the given Resource URI.  The return instance is guaranteed to 
	 * implement the most specific interface in *some* hierarchy in which the Resource participates.  The behavior
	 * is unspecified for resources with RDF types from different hierarchies.
	 * @return an instance of Thing
	 */
	public static Thing getThing(String uri, com.hp.hpl.jena.rdf.model.Model model) throws JastorException {
		return getThing(model.getResource(uri),model);
	}

	/**
	 * Return a list of compatible interfaces for the given type.  Searches through all ontology classes
	 * in the AddressRecord ontology.  The list is sorted according to the topological sort
	 * of the class hierarchy
	 * @return a List of type java.lang.Class
	 */
	public static java.util.List listCompatibleInterfaces (com.hp.hpl.jena.rdf.model.Resource type) {
		java.util.List types = new java.util.ArrayList();
		if (type.equals(golfCourse.ontologies.jastor.location.AddressRecord.TYPE)) {
			types.add(golfCourse.ontologies.jastor.location.AddressRecord.class);
		}
		return types;
	}
}