package golfCourse.translations.fromOTA;

import golfCourse.communication.ontology.ErrorWarning;
import golfCourse.communication.ontology.OWLData;
import golfCourse.exceptions.TranslateException;
import golfCourse.ontologies.jastor.description.Description;
import golfCourse.ontologies.jastor.description.DescriptionFactory;
import golfCourse.ontologies.jastor.fee.FeeFactory;
import golfCourse.ontologies.jastor.golfCourseTeeTime.GolfCourseTeeTime;
import golfCourse.ontologies.jastor.golfCourseTeeTime.GolfCourseTeeTimeFactory;
import golfCourse.ontologies.jastor.price.Price;
import golfCourse.ontologies.jastor.price.PriceFactory;
import golfCourse.ontology.semantic.Memory;
import golfCourse.translations.castor.Errors;
import golfCourse.translations.castor.Fee;
import golfCourse.translations.castor.Fees;
import golfCourse.translations.castor.GolfCourseTeeTimes;
import golfCourse.translations.castor.OTA_GolfCourseAvailRS;
import golfCourse.translations.castor.Warning;
import golfCourse.translations.castor.Warnings;
import jade.util.leap.ArrayList;
import jade.util.leap.List;

import java.io.Reader;
import java.io.StringReader;
import java.math.BigInteger;
import java.text.SimpleDateFormat;

import org.exolab.castor.xml.MarshalException;
import org.exolab.castor.xml.ValidationException;

import com.hp.hpl.jena.ontology.OntModel;
import com.hp.hpl.jena.rdf.model.Resource;
import com.ibm.adtech.jastor.JastorException;

public class GolfCourseAvailRSTranslator {

	private OntModel domainGolfCourseTeeTimeModel;
	private OntModel domainFeeModel;
	private OntModel domainPriceModel;
	private OntModel domainDescriptionModel;
	
	public GolfCourseAvailRSTranslator(OntModel domainGolfCourseTeeTimeModel, 
			OntModel domainFeeModel, OntModel domainPriceModel, OntModel domainDescriptionModel)
	{
		this.domainGolfCourseTeeTimeModel = domainGolfCourseTeeTimeModel;
		this.domainFeeModel = domainFeeModel;
		this.domainPriceModel = domainPriceModel;
		this.domainDescriptionModel = domainDescriptionModel;
	}
	
	public OTA_GolfCourseAvailRS translateToOTA(String otaString) throws TranslateException
	{
		Reader reader = new StringReader(otaString);
		
		try {
			OTA_GolfCourseAvailRS ota = (OTA_GolfCourseAvailRS)OTA_GolfCourseAvailRS.unmarshal(reader);
			return ota;
		}
		catch(MarshalException e)
		{
			throw new TranslateException(" marshal: " + e.toString());
		}
		catch(ValidationException e2)
		{
			throw new TranslateException(" validation: " + e2.toString());
		}
	}
	
	public OWLData translateToOntologies(OTA_GolfCourseAvailRS ota) throws TranslateException
	{
		try {
			ota.getOTA_GolfCourseAvailRSSequence().getUniqueID();
			OWLData ontologies = translate(ota.getOTA_GolfCourseAvailRSSequence().getGolfCourseTeeTimes());
			return ontologies;
		}
		catch(JastorException e3)
		{
			throw new TranslateException(" jastor: " + e3.toString());
		}
	}
	
	public List translateErrors(OTA_GolfCourseAvailRS ota)
	{
		List list = new ArrayList();
		Errors errors = ota.getErrors();
		
		if(errors == null)
			return list;
		
		for(int i = 0; i < errors.getErrorCount(); i++)
		{
			golfCourse.translations.castor.Error error = errors.getError(i);
			ErrorWarning err = new ErrorWarning();
			err.setCode(error.getCode());
			err.setContent(error.getContent());
			err.setStatus(error.getStatus());
			err.setText(error.getShortText());
			list.add(err);
		}
		return list;
	}
	
	public List translateWarnings(OTA_GolfCourseAvailRS ota)
	{
		List list = new ArrayList();
		Warnings warnings = ota.getOTA_GolfCourseAvailRSSequence().getWarnings();
		
		if(warnings == null)
			return list;
		
		for(int i = 0; i < warnings.getWarningCount(); i++)
		{
			Warning warning = warnings.getWarning(i);
			ErrorWarning warn = new ErrorWarning();
			warn.setCode(warning.getCode());
			warn.setContent(warning.getContent());
			warn.setText(warning.getShortText());
			warn.setStatus(warning.getStatus());
			list.add(warn);
		}
		return list;
	}
	
/*	public OWLData translateGolfCourseAvailRSToOntologies(String otaString) throws TranslateException
	{
		Reader reader = new StringReader(otaString);
		
		try {
			OTA_GolfCourseAvailRS ota = (OTA_GolfCourseAvailRS)OTA_GolfCourseAvailRS.unmarshal(reader);
			
			// TODO
			ota.getOTA_GolfCourseAvailRSSequence().getUniqueID();
			OWLData ontologies = translate(ota.getOTA_GolfCourseAvailRSSequence().getGolfCourseTeeTimes());
			return ontologies;
		}catch(MarshalException e)
		{
			throw new TranslateException(" marshal: " + e.toString());
		}
		catch(ValidationException e2)
		{
			throw new TranslateException(" validation: " + e2.toString());
		}
		catch(JastorException e3)
		{
			throw new TranslateException(" jastor: " + e3.toString());
		}
	}*/
	
	/*private void test(OTA_GolfCourseAvailRS ota)
	{
		ota.getAltLangID();
		ota.getErrors();
		ota.getTransactionIdentifier();
		//ota.getOTA_GolfCourseAvailRSSequence().getGolfCourseTeeTimes().getGolfCourseTeeTime()
	}
	
	private void test2(GolfCourseTeeTime ota)
	{
		ota.getAmount();
		ota.getCurrencyCode();
		ota.getEndDate();
		ota.getFee();
		ota.getGolfCourseID();
		ota.getMaxPrice();
		ota.getNumberOfGolfers();
		ota.getNumberOfHoles();
		ota.getStartDate();
	}*/
	
	
	public OWLData translate(GolfCourseTeeTimes golfCourseTeeTimes) throws JastorException
	{
		OWLData ontologies = new OWLData();
		Memory memory = new Memory();
		
		for(int i = 0; i < golfCourseTeeTimes.getGolfCourseTeeTimeCount(); i++)
		{
			golfCourse.translations.castor.GolfCourseTeeTime otaGolfCourseTeeTime = golfCourseTeeTimes.getGolfCourseTeeTime(i);
			
			GolfCourseTeeTime golfCourseTeeTime = translateGolfCourseTeeTime(otaGolfCourseTeeTime);
			
			ontologies.addWithRootURI(golfCourseTeeTime.uri());
			
			Fees fees = otaGolfCourseTeeTime.getFees();
			for(int j = 0; j < fees.getFeeCount(); j++)
			{
				Fee otaFee = fees.getFee(j);
				golfCourse.ontologies.jastor.fee.Fee fee = translate(otaFee);
				
				Price price = translatePrice(otaFee);
				
				fee.setPrice(price);
				
				for(int descIndex = 0; descIndex < otaFee.getDescriptionCount(); descIndex++)
				{
					golfCourse.translations.castor.Description otaDescription = otaFee.getDescription(descIndex);
					Description description = translateDescription(otaDescription);
					fee.addDescription(description);
					memory.add(description);
				}
				
				memory.add(price);
				memory.add(fee);
			}
			
			memory.add(golfCourseTeeTime);
		}
		ontologies.setDataModel(memory.dump());
		return ontologies;
	}
	
	private GolfCourseTeeTime translateGolfCourseTeeTime(golfCourse.translations.castor.GolfCourseTeeTime ota) throws JastorException
	{
		Resource r = domainGolfCourseTeeTimeModel.createResource(GolfCourseTeeTime.TYPE.getNameSpace() + ota.getStart().hashCode());
		GolfCourseTeeTime golfCourseTeeTime = GolfCourseTeeTimeFactory.createGolfCourseTeeTime(r, domainGolfCourseTeeTimeModel);
		
		if(ota.getAmount() != null)
			golfCourseTeeTime.setAmount(new Float(ota.getAmount().floatValue()));
		
		golfCourseTeeTime.setEndDate(ota.getEnd());
		
		if(ota.getMaxPrice() != null)
			golfCourseTeeTime.setMaxPrice(new Float(ota.getMaxPrice().floatValue()));
		
		golfCourseTeeTime.setNumberOfGolfers(BigInteger.valueOf(ota.getNumberOfGolfers()));
		golfCourseTeeTime.setNumberOfHoles(BigInteger.valueOf(ota.getNumberOfHoles()));
		golfCourseTeeTime.setNumberOfTimes(BigInteger.valueOf(ota.getNumberOfTimes()));
		
		// TODO add membership
		golfCourseTeeTime.setStartDate(ota.getStart());
		
		return golfCourseTeeTime;
	}
	
	private Description translateDescription(golfCourse.translations.castor.Description otaDescription) throws JastorException
	{
		Resource r = domainDescriptionModel.createResource(Description.TYPE.getNameSpace() + otaDescription.getCreatorID()+ "_" + otaDescription.getName());
		Description description = DescriptionFactory.createDescription(r, domainDescriptionModel);
		
		if(otaDescription.getCreateDateTime() != null)
			description.setCreateDateTime(translateDate(otaDescription.getCreateDateTime()));
		description.setName(otaDescription.getName());
		
		// TODO add something not only name - maybe some context
		return description;
	}
	
	private Price translatePrice(Fee otaFee) throws JastorException
	{
		Resource r = domainPriceModel.createResource(Price.TYPE.getNameSpace() + otaFee.hashCode());
		Price price = PriceFactory.createPrice(r, domainPriceModel);
		
		if(otaFee.getAmount() != null)
			price.setAmount(new Float(otaFee.getAmount().floatValue()));
		price.setCurrencyCode(otaFee.getCurrencyCode());
		
		if(otaFee.getPercent() != null)
			price.setPercent(new Float(otaFee.getPercent().floatValue()));
		
		price.setTaxInclusive(new Boolean(otaFee.getTaxInclusive()));
		
		// TODO add taxes
		return price;
	}
	
	private golfCourse.ontologies.jastor.fee.Fee translate(Fee otaFee) throws JastorException
	{
		Resource r = domainFeeModel.createResource(golfCourse.ontologies.jastor.fee.Fee.TYPE.getNameSpace() + otaFee.hashCode());
		
		golfCourse.ontologies.jastor.fee.Fee fee = FeeFactory.createFee(r, domainFeeModel);
		
		fee.addDescription();
		
		if(otaFee.getEffectiveDate() != null)
			fee.setEffectiveDate(translateDate(otaFee.getEffectiveDate().toDate()));
		
		if(otaFee.getExpireDate() != null)
			fee.setExpireDate(translateDate(otaFee.getExpireDate().toDate()));
		
		return fee;
	}
	
	private String translateDate(java.util.Date date)
	{
		SimpleDateFormat formatter = new SimpleDateFormat ("yyyy-MM-dd");
		return formatter.format(date);
	}
}

