package golfCourse.translations.fromOTA;

import golfCourse.communication.ontology.Condition;
import golfCourse.communication.ontology.Conditions;
import golfCourse.exceptions.TranslateException;
import golfCourse.properties.ConditionOperation;
import golfCourse.translations.ConditionsVocabulary;
import golfCourse.translations.castor.Criteria;
import golfCourse.translations.castor.Criterion;
import golfCourse.translations.castor.OTA_GolfCourseSearchRQ;

import java.io.Reader;
import java.io.StringReader;
import java.util.Iterator;

import org.exolab.castor.xml.MarshalException;
import org.exolab.castor.xml.ValidationException;

public class GolfCourseSearchRQTranslator {
	
	public static Conditions translateFromOTA(String text) throws TranslateException
	{
		Conditions conditions = new Conditions();
		
		Reader reader = new StringReader(text);
		
		try {
			OTA_GolfCourseSearchRQ ota = (OTA_GolfCourseSearchRQ)OTA_GolfCourseSearchRQ.unmarshal(reader);
			conditions = translateGolfCourseSearchRQ(ota);
		}catch(MarshalException e)
		{
			throw new TranslateException(" marshal: " + e.toString());
		}
		catch(ValidationException e2)
		{
			throw new TranslateException(" validation: " + e2.toString());
		}
		return conditions;
	}
	
	private static Conditions translateGolfCourseSearchRQ(OTA_GolfCourseSearchRQ ota) throws TranslateException
	{
		Conditions conditions = new Conditions();
		
		Criteria criteria = ota.getCriteria();
		
		for(int i = 0; i < criteria.getCriterionCount(); i++)
		{
			Criterion criterion = criteria.getCriterion(i);
			Condition condition = translateCondition(criterion);
			conditions.addConditions(condition);
		}	
		return conditions;
	}

	private static Condition translateCondition(Criterion criterion) throws TranslateException
	{
		Condition condition = new Condition();
		// TODO convertion to String???
		condition.setName_(translateName((String)criterion.getName()));
				
		// TODO convertion to String???
		condition.setOperation_(translateOperation((String)criterion.getOperation()));
		condition.setRequired_(criterion.getRequired());
		
//		 TODO convertion to String???
		condition.setValueString((String)criterion.getValue());
		return condition;
	}
	
	private static String translateName(String name) throws TranslateException{
		if(name.equals(ConditionsVocabulary.OTA_ARCHITECT))
			return ConditionsVocabulary.ONT_ARCHITECT;
		if(name.equals(ConditionsVocabulary.OTA_SINGLESS_CONFIRMED))
			return ConditionsVocabulary.ONT_SINGLESS_CONFIRMED;
		if(name.equals(ConditionsVocabulary.ONT_ADA_CHALLENGED))
			return ConditionsVocabulary.ONT_ADA_CHALLENGED;
		if(name.equals(ConditionsVocabulary.OTA_SLOPE))
			return ConditionsVocabulary.ONT_SLOPE;
		if(name.equals(ConditionsVocabulary.OTA_METAL_SPIKES))
			return ConditionsVocabulary.ONT_METAL_SPIKES;
		if(name.equals(ConditionsVocabulary.OTA_CADDIES_AVAILABLE))
			return ConditionsVocabulary.ONT_CADDIES_AVAILABLE;
		if(name.equals(ConditionsVocabulary.OTA_YARDAGE))
			return ConditionsVocabulary.ONT_YARDAGE;
		if(name.equals(ConditionsVocabulary.OTA_PERSONAL_CARTS))
			return ConditionsVocabulary.ONT_PERSONAL_CARTS;
		if(name.equals(ConditionsVocabulary.OTA_GRASS_TYPE))
			return ConditionsVocabulary.ONT_GRASS_TYPE;
		throw new TranslateException("translate name");
		//if(name.equals("Fivesome"))
		//	return "fivesome";
		//if(name.equals("Grass Type"))
		//	return "grass";
	}
	
	private static String translateOperation(String op) {
		if( op== null)
			return ConditionOperation.EQUAL;
		
		if(op.equals(ConditionsVocabulary.OTA_NO_OPERATION))
			return ConditionOperation.EQUAL;
		
		if(op.equals(ConditionsVocabulary.OTA_GREATER_THAN_OPERATION) ||
				op.equals(ConditionsVocabulary.OTA_GREATER_THAN_OPERATION2))
			return ConditionOperation.GREATER_THAN;
		
		if(op.equals(ConditionsVocabulary.OTA_GREATER_THAN_OR_EQUAL_OPERATION) ||
				op.equals(ConditionsVocabulary.OTA_GREATER_THAN_OR_EQUAL_OPERATION2))
			return ConditionOperation.GREATER_THAN_OR_EQUAL;
		
		if(op.equals(ConditionsVocabulary.OTA_LESS_THAN_OPERATION) ||
				op.equals(ConditionsVocabulary.OTA_LESS_THAN_OPERATION2))
			return ConditionOperation.LESS_THAN;
		
		if(op.equals(ConditionsVocabulary.OTA_NOT_EQUAL_OPERATION) ||
				op.equals(ConditionsVocabulary.OTA_NOT_EQUAL_OPERATION2))
			return ConditionOperation.NOT_EQUAL;
		
		//if("LessThan".equals(op))
		//	return "<";
		//return op;
		return ConditionOperation.EQUAL;
	}

}
