package golfCourse.translations.toOTA;

import golfCourse.communication.ontology.Map;
import golfCourse.exceptions.TranslateException;
import golfCourse.ontology.semantic.OntologyTools;
import golfCourse.translations.GolfCourseAvailMapVocabulary;
import golfCourse.translations.castor.GolfCourseTeeTime;
import golfCourse.translations.castor.GolfCourseTeeTimes;
import golfCourse.translations.castor.OTA_GolfCourseAvailRQ;

import java.io.StringWriter;
import java.io.Writer;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import org.exolab.castor.xml.MarshalException;
import org.exolab.castor.xml.ValidationException;


public class GolfCourseAvailRQTranslator {

	public String translate(String golfCourseID, String start, String end, 
			int numberOfGolfers, int numberOfHoles, int numberOfTimes, float maxPrice, String currencyCode) throws TranslateException 
	{
		OTA_GolfCourseAvailRQ ota = translateToOTA(golfCourseID, start, end, numberOfGolfers,
				numberOfHoles, numberOfTimes, maxPrice, currencyCode);
		
		ota.setVersion(new BigDecimal(12));
		
		Writer writer = new StringWriter();
		try {
			ota.marshal(writer);
		}
		catch(MarshalException e)
		{
			throw new TranslateException("Marshal exception " + e);
		}
		catch(ValidationException e2)
		{
			throw new TranslateException("Validation exception " + e2);
		}	
		
		return writer.toString();
	}
	
	private OTA_GolfCourseAvailRQ translateToOTA(String golfCourseID, String start, String end, 
			int numberOfGolfers, int numberOfHoles, int numberOfTimes, float maxPrice, String currencyCode) 
	{
		OTA_GolfCourseAvailRQ ota = new OTA_GolfCourseAvailRQ();
		
		GolfCourseTeeTimes golfCourseTeeTimes = new GolfCourseTeeTimes();
		
		GolfCourseTeeTime golfCourseTeeTime = new GolfCourseTeeTime();
		golfCourseTeeTime.setMaxPrice(new BigDecimal(maxPrice));
		golfCourseTeeTime.setCurrencyCode(currencyCode);
		
		if(start != null)
			//golfCourseTeeTime.setStart(translateDate(start));
			golfCourseTeeTime.setStart(start);
		
		if(end != null)
			//golfCourseTeeTime.setEnd(translateDate(end));
			golfCourseTeeTime.setEnd(end);
		
		golfCourseTeeTime.setNumberOfGolfers(numberOfGolfers);
		golfCourseTeeTime.setNumberOfHoles(numberOfHoles);
		golfCourseTeeTime.setNumberOfTimes(numberOfTimes);
		
		golfCourseTeeTimes.addGolfCourseTeeTime(golfCourseTeeTime);
		
		ota.setGolfCourseTeeTimes(golfCourseTeeTimes);
		
		return ota;
	}
	
	private String translateDate(Date date) {
		
		SimpleDateFormat formatter = new SimpleDateFormat ("yyyy-MM-dd'T'HH:mm:ss");
		
		return formatter.format(date);
	}
	
	public String translateToOTA(Map map) throws TranslateException
	{
		java.util.Map hashMap = OntologyTools.getMap(map);
		
		String golfCourseId = (String)hashMap.get(GolfCourseAvailMapVocabulary.GOLF_COURSE_ID);
		
		String startDate = (String)hashMap.get(GolfCourseAvailMapVocabulary.START_DATE);
		String endDate = (String)hashMap.get(GolfCourseAvailMapVocabulary.END_DATE);
		int numberOfGolfers = Integer.parseInt((String)hashMap.get(GolfCourseAvailMapVocabulary.NUMBER_OF_GOLFERS));
		int numberOfHoles = Integer.parseInt((String)hashMap.get(GolfCourseAvailMapVocabulary.NUMBER_OF_HOLES));;
		int numberOfTimes = Integer.parseInt((String)hashMap.get(GolfCourseAvailMapVocabulary.NUMBER_OF_TIMES));;
		float maxPrice = Integer.parseInt((String)hashMap.get(GolfCourseAvailMapVocabulary.MAX_PRICE));;
		String currencyCode = (String)hashMap.get(GolfCourseAvailMapVocabulary.CURRENCY_CODE);
		
		String ota = translate(golfCourseId, startDate, endDate, numberOfGolfers, numberOfHoles, numberOfTimes, maxPrice, currencyCode);
		
		return ota;
	}
	
	
}
