package golfCourse.translations.toOTA;

import golfCourse.exceptions.TranslateException;
import golfCourse.translations.castor.Address;
import golfCourse.translations.castor.Cancel;
import golfCourse.translations.castor.CardIssuerName;
import golfCourse.translations.castor.Charge;
import golfCourse.translations.castor.Charges;
import golfCourse.translations.castor.CountryName;
import golfCourse.translations.castor.Description;
import golfCourse.translations.castor.GolfCourseRes;
import golfCourse.translations.castor.GolfCoursesRes;
import golfCourse.translations.castor.Golfer;
import golfCourse.translations.castor.Golfers;
import golfCourse.translations.castor.Membership;
import golfCourse.translations.castor.Memberships;
import golfCourse.translations.castor.OTA_GolfCourseResRS;
import golfCourse.translations.castor.OTA_GolfCourseResRSSequence;
import golfCourse.translations.castor.PaymentCard;
import golfCourse.translations.castor.PaymentForm;
import golfCourse.translations.castor.PersonName;
import golfCourse.translations.castor.RateQualifier;
import golfCourse.translations.castor.RateQualifiers;
import golfCourse.translations.castor.ResID;
import golfCourse.translations.castor.Round;
import golfCourse.translations.castor.Rounds;
import golfCourse.translations.castor.StateProv;
import golfCourse.translations.castor.StreetNmbr;
import golfCourse.translations.castor.Success;
import golfCourse.translations.castor.Telephone;
import golfCourse.translations.castor.types.GolferTypeGenderType;
import golfCourse.translations.castor.types.OTA_GolfCourseResRSTargetType;

import java.io.StringWriter;
import java.io.Writer;
import java.math.BigDecimal;
import java.util.Date;

import org.exolab.castor.xml.MarshalException;
import org.exolab.castor.xml.ValidationException;

public class GolfCourseResRSTranslator {
	
	public static void main(String[] args) {
		GolfCourseResRSTranslator translator = new GolfCourseResRSTranslator();
		try {
			String ota = translator.translate();
			System.out.println(ota);
		} catch(TranslateException e) {
			System.out.println("translate exception: " + e.toString());
		}
	}
	
	public String translate() throws TranslateException 
	{
		OTA_GolfCourseResRS ota = translateToOTA();
		
		Writer writer = new StringWriter();
		try {
			ota.marshal(writer);
		}
		catch(MarshalException e)
		{
			throw new TranslateException("Marshal exception " + e);
		}
		catch(ValidationException e2)
		{
			throw new TranslateException("Validation exception " + e2);
		}	
		
		return writer.toString();
	}
	
	public OTA_GolfCourseResRS translateToOTA() {
		OTA_GolfCourseResRS ota = new OTA_GolfCourseResRS();
		
		ota.setEchoToken("12345");
		ota.setTimeStamp(new Date());
		ota.setTarget(OTA_GolfCourseResRSTargetType.PRODUCTION);
		ota.setVersion(new BigDecimal(1.002));
		ota.setSequenceNmbr(123456);
		ota.setID("FL1234");
		
		GolfCoursesRes golfCoursesRes = new GolfCoursesRes();
		
		GolfCourseRes golfCourseRes = new GolfCourseRes();
		golfCourseRes.setStatus("New");
		golfCourseRes.setStatusMessage("New Reservation Request");
		golfCourseRes.setResponderResConfID("11223344");
		golfCourseRes.setRequestorResID("22113344");
		
		Rounds rounds = translateRounds();
		golfCourseRes.setRounds(rounds);
		
		ResID resID = new ResID();
		resID.setType("14");
		resID.setID("123");
		golfCourseRes.setResID(resID);
		
		golfCoursesRes.addGolfCourseRes(golfCourseRes);
		
		// sequence
		OTA_GolfCourseResRSSequence otaGolfCourseResRSSequence = new OTA_GolfCourseResRSSequence();
		otaGolfCourseResRSSequence.setGolfCoursesRes(golfCoursesRes);
		Success success = new Success();
		otaGolfCourseResRSSequence.setSuccess(success);
		ota.setOTA_GolfCourseResRSSequence(otaGolfCourseResRSSequence);
		
		return ota;
	}
	
	private Rounds translateRounds() {
		Rounds rounds = new Rounds();
		
		Round round = new Round();
		round.setRoundID(23456);
		round.setPlayDateTime("2003-06-10T11:00:00");
		round.setNumberOfGolfers(2);
		round.setStartingTee("1");
		round.setNumberOfCarts(1);
		round.setAmount(new BigDecimal(140.00));
		round.setCurrencyCode("USD");
		
		Cancel cancel = translateCancel();
		round.setCancel(cancel);
		
		Charges charges = new Charges();
		Charge charge = new Charge();
		charge.setTaxInclusive(true);
		charge.setCode("7");
		charge.setAmount(new BigDecimal(70.00));
		charge.setCurrencyCode("USD");
		
		Description description = new Description();
		description.setName("Standard Rate - Tourist");
		description.setLanguage("EN");
		Description[] descriptionArray = new Description[1];
		charge.setDescription(descriptionArray);
		charge.setDescription(0, description);
		
		charges.addCharge(charge);
		round.setCharges(charges);
		
		Golfers golfers = translateGolfers();
		round.setGolfers(golfers);
		
		RateQualifiers rateQualifiers = new RateQualifiers();
		RateQualifier rateQualifier = new RateQualifier();
		rateQualifier.setRateQualifier("NGCOA");
		rateQualifiers.addRateQualifier(rateQualifier);
		round.setRateQualifiers(rateQualifiers);
		
		rounds.addRound(round);
		return rounds;
	}
	
	private Cancel translateCancel() {
		Cancel cancel = new Cancel();
		cancel.setCancelByDate("2003-06-10T11:06:00");
		cancel.setAmount(new BigDecimal(55.00));
		cancel.setCurrencyCode("USD");
		return cancel;
	}
	
	private Golfers translateGolfers() {
		Golfers golfers = new Golfers();
		
		Golfer golfer = new Golfer();
		
		golfer.setGender(GolferTypeGenderType.MALE);
		golfer.setBirthDate(new org.exolab.castor.types.Date());
		
		// memberships
		Memberships memberships = new Memberships();
		Membership membership = new Membership();
		membership.setProgramID("NGCOA");
		membership.setMembershipID("4123546");
		memberships.addMembership(membership);
		golfer.setMemberships(memberships);
		
		// payment form
		PaymentForm paymentForm = new PaymentForm();
		PaymentCard paymentCard = new PaymentCard();
		paymentCard.setCardType("1");
		paymentCard.setCardCode("AX");
		paymentCard.setCardNumber("3145234356876223");
		paymentCard.setSeriesCode("1122334");
		paymentCard.setEffectiveDate("0800");
		paymentCard.setExpireDate("0804");
		paymentCard.setCardHolderName("Mr. Bobby Jones");
		CardIssuerName cardIssuerName = new CardIssuerName();
		cardIssuerName.setBankID("1122334455");
		paymentCard.setCardIssuerName(cardIssuerName);
		// we can put something else, not only payment card
		paymentForm.setPaymentCard(paymentCard);
		golfer.setPaymentForm(paymentForm);
		
		// person name
		PersonName personName = new PersonName();
		personName.addNamePrefix("Mr.");
		personName.addGivenName("Bobby");
		personName.setSurname("Jones");
		golfer.setPersonName(personName);
		
		// address
		Address address = new Address();
		address.setType("1");
		StreetNmbr streetNmbr = new StreetNmbr();
		streetNmbr.setContent("123 Augusta Lane");
		address.setStreetNmbr(streetNmbr);
		address.setCityName("Atlanta");
		address.setPostalCode("23456");
		StateProv stateProv = new StateProv();
		stateProv.setStateCode("GA");
		stateProv.setContent("Georgia");
		address.setStateProv(stateProv);
		CountryName countryName = new CountryName();
		countryName.setCode("US");
		countryName.setContent("United States");
		address.setCountryName(countryName);
		golfer.setAddress(address);
		
		// telephone
		Telephone telephone = new Telephone();
		telephone.setPhoneTechType("1");
		telephone.setCountryAccessCode("1");
		telephone.setAreaCityCode("703");
		telephone.setPhoneNumber("444-5555");
		golfer.setTelephone(telephone);
		
		golfers.addGolfer(golfer);
		
		return golfers;
	}


}
