package personalSystem.PersonalAgent;

import golfCourse.Tools;
import golfCourse.communication.ontology.GolfCourseOntology;
import jade.content.lang.Codec;
import jade.content.lang.sl.SLCodec;
import jade.content.onto.Ontology;
import jade.core.Agent;
import jade.domain.FIPANames;
import jade.util.Logger;

import java.io.IOException;
import java.util.Properties;

/**
 * This agent send Conditions and Map for GolfCourseAvailRQ.
 * Write ontologies GolfCourseTeeTime to file.
 */
public class PersonalAgent extends Agent{
	
	private static Logger logger = Logger.getMyLogger(PersonalAgent.class.getName());

	public Codec codec = new SLCodec();
	
	public Ontology golfCourseOntology = GolfCourseOntology.getInstance();
	
	public String language = FIPANames.ContentLanguage.FIPA_SL0;
	
	private static String CUSTOMER_CONVERSATION_ID = "CUSTOMER_CONVERSATION_ID";
	private static String MAP = "MAP";
	private static String CONDITIONS = "CONDITIONS";
	
	
	public String customerConversationId = "1";
	public String generateMap = "";
	public String generateConditions = "";
	
	public PersonalAgent()
	{
		registerLanguage();
		registerOntology();
		readMessagesProperties();
		addBehaviour(new PersonalAgentBehaviour(this));
	}
	
	/**
	 * Register language of messages in system.
	 */
	private void registerLanguage()
	{
		getContentManager().registerLanguage(codec, language);
	}
	
	/**
	 * Register messages ontology.
	 */
	private void registerOntology()
	{
		getContentManager().registerOntology(golfCourseOntology);
	}
	
	/**
	 * 
	 */
	public void setup()
	{
		
	}
	
	private void readMessagesProperties()
	{
		try {
			Properties props = Tools.loadProperties(PersonalAgentProperties.USER_MESSAGES);
			customerConversationId = props.getProperty(CUSTOMER_CONVERSATION_ID);
			generateMap = props.getProperty(MAP);
			generateConditions = props.getProperty(CONDITIONS);
		}
		catch(IOException e)
		{
			logger.info("Personal Agent: error during reading messages properties file - " + e.getMessage());
			doDelete();
		}
	}

}
